diff --git a/Scripts/Functions/Render/Svg/svg_convertPngTo.sh b/Scripts/Functions/Render/Svg/svg_convertPngTo.sh
index 5b5890b..8374363 100644
--- a/Scripts/Functions/Render/Svg/svg_convertPngTo.sh
+++ b/Scripts/Functions/Render/Svg/svg_convertPngTo.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # render_convertPngTo.sh -- This function provides post-rendition
 # actions to use the `convert' command of ImageMagick tool set.
 #
 # Copyright (C) 2009, 2010, 2011 The CentOS Project
@@ -23,7 +23,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function render_convertPngTo {
+function svg_convertPngTo {
 
     # Get image formats.
     local FORMATS=$(render_getConfigOption "$ACTION" '2')
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# render_convertPngTo.sh -- This function provides post-rendition
+# svg_convertPngTo.sh -- This function provides post-rendition
 # actions to use the `convert' command of ImageMagick tool set.
 #